/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _INITRD_H
#define _INITRD_H

/** @file
 *
 * Initial ramdisk (initrd) reshuffling
 *
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <gpxe/uaccess.h>

/** Minimum alignment for initrds
 *
 * Some versions of Linux complain about initrds that are not
 * page-aligned.
 */
#define INITRD_ALIGN 4096

/** Minimum free space required to reshuffle initrds
 *
 * Chosen to avoid absurdly long reshuffling times
 */
#define INITRD_MIN_FREE_LEN ( 512 * 1024 )

extern void initrd_reshuffle ( userptr_t bottom );
extern int initrd_reshuffle_check ( size_t len, userptr_t bottom );

#endif /* _INITRD_H */
