/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <stdint.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include <gpxe/iscsi.h>
#include <gpxe/settings.h>
#include <gpxe/sf_settings.h>
#include <gpxe/dhcp.h>
#include <gpxe/netdevice.h>
#include <gpxe/ibft.h>
#include <gpxe/init.h>
#include <gpxe/bootconn.h>
#include <gpxe/tcp.h>
#include <int13.h>
#include <usr/autoboot.h>
#include <usr/bootconnect.h>

int iscsiconnect ( const char *root_path ) {
	struct scsi_device *scsi;
	struct int13_drive *drive;
	int rc = 0;

	scsi = zalloc ( sizeof ( *scsi ) );
	if ( ! scsi ) {
		rc = -ENOMEM;
		goto err_alloc_scsi;
	}
	drive = zalloc ( sizeof ( *drive ) );
	if ( ! drive ) {
		rc = -ENOMEM;
		goto err_alloc_drive;
	}

	printf ( "iSCSI connection to %s\n", root_path );

	if ( ( rc = iscsi_attach ( scsi, root_path ) ) != 0 ) {
		printf ( "Could not attach iSCSI device: %s\n",
			 strerror ( rc ) );
		goto err_attach;
	}
	if ( ( rc = init_scsidev ( scsi ) ) != 0 ) {
		printf ( "Could not initialise iSCSI device: %s\n",
			 strerror ( rc ) );
		goto err_init;
	}

	drive->blockdev = &scsi->blockdev;

	struct iscsi_session *iscsi =
		container_of ( scsi->backend, struct iscsi_session, refcnt );
	if ( ( rc = ibft_fill_iscsi ( iscsi ) ) != 0 ) {
		printf ( "Error: Failed to populate iBFT: %s\n",
			 strerror( rc ) );
		goto err_ibft;
	}

	drive->drive = -1;  /* use natural drive number */
	register_int13_drive ( drive );
	printf ( "Registered as BIOS drive %#02x\n", drive->drive );

	/* Logout for now */
	iscsi_logout ( scsi );

	/* Wait up to 1s for connections to close */
	tcp_wait_for_closures ( 1000 );

	return rc;

 err_ibft:
 err_init:
 err_attach:
	free ( drive );
 err_alloc_drive:
 err_alloc_scsi:
	return rc;
}

struct bootconn_protocol iscsi_bootconn_protocol __bootconn_protocol = {
	.prefix = "iscsi:",
	.connect = iscsiconnect,
};
