/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#include <errno.h>
#include <comboot.h>
#include <gpxe/in.h>
#include <gpxe/list.h>
#include <gpxe/process.h>
#include <gpxe/resolv.h>

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

struct comboot_resolver {
	struct interface intf;
	int rc;
	struct in_addr addr;
};

static void comboot_resolv_close ( struct comboot_resolver *comboot_resolver,
				   int rc ) {
	comboot_resolver->rc = rc;
	intf_shutdown ( &comboot_resolver->intf, rc );
}

static void comboot_resolv_done ( struct comboot_resolver *comboot_resolver,
				  struct sockaddr *sa ) {
	struct sockaddr_in *sin;

	if ( sa->sa_family == AF_INET ) {
		sin = ( ( struct sockaddr_in * ) sa );
		comboot_resolver->addr = sin->sin_addr;
	}
}

static struct interface_operation comboot_resolv_op[] = {
	INTF_OP ( intf_close, struct comboot_resolver *, comboot_resolv_close ),
	INTF_OP ( resolv_done, struct comboot_resolver *, comboot_resolv_done ),
};

static struct interface_descriptor comboot_resolv_desc =
	INTF_DESC ( struct comboot_resolver, intf, comboot_resolv_op );

static struct comboot_resolver comboot_resolver = {
	.intf = INTF_INIT ( comboot_resolv_desc ),
};

int comboot_resolv ( const char *name, struct in_addr *address ) {
	int rc;

	comboot_resolver.rc = -EINPROGRESS;
	comboot_resolver.addr.s_addr = 0;

	if ( ( rc = resolv ( &comboot_resolver.intf, name, NULL ) ) != 0 )
		return rc;

	while ( comboot_resolver.rc == -EINPROGRESS )
		step();

	if ( ! comboot_resolver.addr.s_addr )
		return -EAFNOSUPPORT;

	*address = comboot_resolver.addr;
	return comboot_resolver.rc;
}
