/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _DRIVERS_NET_MII_H
#define _DRIVERS_NET_MII_H

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

/** @file
 *
 * MII constants
 *
 */

/* Link partner ability register. */
#define LPA_10HALF              0x0020  /* Can do 10mbps half-duplex   */
#define LPA_10FULL              0x0040  /* Can do 10mbps full-duplex   */
#define LPA_100HALF             0x0080  /* Can do 100mbps half-duplex  */
#define LPA_100FULL             0x0100  /* Can do 100mbps full-duplex  */

/* Pseudo extensions to the link partner ability register */
#define LPA_1000FULL		0x00020000
#define LPA_1000HALF		0x00010000
#define LPA_10000FULL		0x00040000
#define LPA_40000FULL		0x00080000

#define LPA_10			( LPA_10FULL | LPA_10HALF )
#define LPA_100			( LPA_100FULL | LPA_100HALF )
#define LPA_1000		( LPA_1000FULL | LPA_1000HALF )
#define LPA_10000               ( LPA_10000FULL )
#define LPA_DUPLEX		( LPA_10FULL | LPA_100FULL | LPA_1000FULL | \
				  LPA_10000FULL )

/* Mask of bits not associated with speed or duplexity. */
#define LPA_OTHER		~( LPA_10FULL | LPA_10HALF | LPA_100FULL | \
				   LPA_100HALF | LPA_1000FULL | LPA_1000HALF )

#endif /* _DRIVERS_NET_MII_H */
