#!/bin/env perl
######################################################################
#
# SPDX-License-Identifier: GPL-2.0+
#
# Driver for Solarflare network controllers and boards
# Copyright 2019 Solarflare Communications Inc.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation, incorporated herein by reference.
#
# You can also choose to distribute this program under the terms of
# the Unmodified Binary Distribution Licence (as given in the file
# COPYING.UBDL), provided that you have satisfied its requirements.
#
######################################################################
#
# Concatenate several PXE ROM images together

use strict;
use warnings;
use constant ROM_SIGNATURE => 0xaa55;

use FindBin;
use lib "$FindBin::Bin";
use Option::ROM qw ( :all );

my $romout = shift @ARGV;
my @romfiles = @ARGV;
my %roms;
my $numroms = scalar(@romfiles);

@romfiles || die("usage: $0 <rom output> <rom input> [<rom inputs>*]");

# Load ROMs
foreach my $rom (@romfiles) {
    $roms{$rom} = new Option::ROM;
    $roms{$rom}->load($rom);
    printf "Input: %s len:%d\n", $rom, $roms{$rom}->length;
}
print "Output: $romout\n";

# Check ROMs
foreach my $rom (@romfiles) {
    ($roms{$rom}->{signature} == ROM_SIGNATURE) || die("Incorrect signature for '$rom'");

    (my @stat = stat($rom)) || die("Could not stat '$rom'");
    ($roms{$rom}->length == $stat[7]) || die("File length does not match header for '$rom'");

    ($roms{$rom}->pci_header->{last_image} == 0x80) || die("Unsupported muliple images in '$rom'");
}

# Modify ROMs and output
for (my $i=0; $i<$numroms ; $i++ ) {
    my $rom = $romfiles[$i];
    $roms{$rom}->pci_header->{last_image} = ($i==$numroms-1) ? 0x80 : 0;
    $roms{$rom}->fix_checksum();
    $roms{$rom}->save($romout, $i!=0);
}
